@@ -231,7 +231,7 @@
 
   # ==== remove Component column if not needed
 
-  if (!is.null(parameters$Component) && insight::n_unique(parameters$Component) == 1 && !keep_component_column) parameters$Component <- NULL # nolint
+  if (!is.null(parameters$Component) && insight::has_single_value(parameters$Component, remove_na = TRUE) && !keep_component_column) parameters$Component <- NULL # nolint
   if ((!is.null(parameters$Effects) && insight::n_unique(parameters$Effects) == 1) || effects == "fixed") parameters$Effects <- NULL # nolint
 
 
@@ -325,7 +325,6 @@
 }
 
 
-
 .filter_parameters <- function(params, keep = NULL, drop = NULL, verbose = TRUE) {
   if (!is.null(keep) && is.list(keep)) {
     for (i in names(keep)) {
@@ -648,7 +647,6 @@
 }
 
 
-
 .add_within_between_effects <- function(model, parameters) {
   # This function checks whether the model contains predictors that were
   # "demeaned" using the "demean()" function. If so, these columns have an
@@ -703,7 +701,6 @@
 }
 
 
-
 .find_within_between <- function(model, which_effect) {
   mf <- stats::model.frame(model)
   unlist(sapply(names(mf), function(i) {
@@ -714,10 +711,6 @@
 }
 
 
-
-
-
-
 # Bayes function ------------------------------------------------------
 
 
@@ -825,10 +818,10 @@
   }
 
   # Remove unnecessary columns
-  if ("CI" %in% names(parameters) && insight::n_unique(parameters$CI) == 1) {
+  if ("CI" %in% names(parameters) && insight::has_single_value(parameters$CI, remove_na = TRUE)) {
     parameters$CI <- NULL
   }
-  if ("ROPE_CI" %in% names(parameters) && insight::n_unique(parameters$ROPE_CI) == 1) {
+  if ("ROPE_CI" %in% names(parameters) && insight::has_single_value(parameters$ROPE_CI, remove_na = TRUE)) {
     parameters$ROPE_CI <- NULL
   }
   if ("ROPE_low" %in% names(parameters) && "ROPE_high" %in% names(parameters)) {
@@ -846,13 +839,13 @@
   }
 
   rownames(parameters) <- NULL
+  # indicate it's a Bayesian model
+  attr(parameters, "is_bayesian") <- TRUE
+
   parameters
 }
 
 
-
-
-
 # SEM function ------------------------------------------------------
 
 
@@ -1010,7 +1003,6 @@
 }
 
 
-
 # tools -------------------------
 
 
