@@ -11,9 +11,10 @@
 #'
 #' @param model A mixed model.
 #' @param effects Should parameters for fixed effects (`"fixed"`), random
-#'   effects (`"random"`), or both (`"all"`) be returned? Only applies
-#'   to mixed models. May be abbreviated. If the calculation of random effects
-#'   parameters takes too long, you may use `effects = "fixed"`.
+#'   effects (`"random"`), both fixed and random effects (`"all"`), or the
+#'   overall (sum of fixed and random) effects (`"random_total"`) be returned?
+#'   Only applies to mixed models. May be abbreviated. If the calculation of
+#'   random effects parameters takes too long, you may use `effects = "fixed"`.
 #' @param wb_component Logical, if `TRUE` and models contains within- and
 #'   between-effects (see `datawizard::demean()`), the `Component` column
 #'   will indicate which variables belong to the within-effects,
@@ -170,8 +171,7 @@ model_parameters.glmmTMB <- function(model,
                                      group_level = FALSE,
                                      exponentiate = FALSE,
                                      p_adjust = NULL,
-                                     wb_component = TRUE,
-                                     summary = getOption("parameters_mixed_summary", FALSE),
+                                     wb_component = FALSE,
                                      include_info = getOption("parameters_mixed_info", FALSE),
                                      include_sigma = FALSE,
                                      keep = NULL,
@@ -180,12 +180,6 @@ model_parameters.glmmTMB <- function(model,
                                      ...) {
   insight::check_if_installed("glmmTMB")
 
-  ## TODO remove deprecated later
-  if (!missing(summary)) {
-    .deprecated_warning("summary", "include_info", verbose)
-    include_info <- summary
-  }
-
   # validation check, warn if unsupported argument is used.
   dot_args <- .check_dots(
     dots = list(...),
@@ -200,13 +194,21 @@ model_parameters.glmmTMB <- function(model,
   # which components to return?
   effects <- insight::validate_argument(
     effects,
-    c("fixed", "random", "all")
+    c("fixed", "random", "total", "random_total", "all")
   )
   component <- insight::validate_argument(
     component,
     c("all", "conditional", "zi", "zero_inflated", "dispersion")
   )
 
+  # for coef(), we don't need all the attributes and just stop here
+  if (effects %in% c("total", "random_total")) {
+    params <- .group_level_total(model)
+    params$Effects <- "total"
+    class(params) <- c("parameters_coef", "see_parameters_coef", class(params))
+    return(params)
+  }
+
   # standardize only works for fixed effects...
   if (!is.null(standardize) && standardize != "refit") {
     if (!missing(effects) && effects != "fixed" && verbose) {
