@@ -117,9 +117,6 @@ print_md.parameters_brms_meta <- print_md.parameters_model
 print_md.parameters_simulate <- print_md.parameters_model
 
 
-
-
-
 # compare parameters -------------------------
 
 
@@ -176,6 +173,12 @@ print_md.compare_parameters <- function(x,
     engine = engine
   )
 
+  # replace brackets by parenthesis
+  if (!is.null(ci_brackets) && "Parameter" %in% colnames(formatted_table)) {
+    formatted_table$Parameter <- gsub("[", ci_brackets[1], formatted_table$Parameter, fixed = TRUE)
+    formatted_table$Parameter <- gsub("]", ci_brackets[2], formatted_table$Parameter, fixed = TRUE)
+  }
+
   if (identical(engine, "tt")) {
     # retrieve output format - print_md() may be called from print_html()
     dots <- list(...)
@@ -204,9 +207,6 @@ print_md.compare_parameters <- function(x,
 }
 
 
-
-
-
 # SEM print ----------------------------
 
 #' @export
@@ -243,8 +243,6 @@ print_md.parameters_sem <- function(x,
 }
 
 
-
-
 # PCA / EFA / CFA ----------------------------
 
 #' @export
@@ -279,13 +277,14 @@ print_md.parameters_efa <- function(x, digits = 2, sort = FALSE, threshold = NUL
 print_md.parameters_pca <- print_md.parameters_efa
 
 
-
-
-
 # Equivalence test ----------------------------
 
 #' @export
-print_md.equivalence_test_lm <- function(x, digits = 2, ci_brackets = c("(", ")"), zap_small = FALSE, ...) {
+print_md.equivalence_test_lm <- function(x,
+                                         digits = 2,
+                                         ci_brackets = c("(", ")"),
+                                         zap_small = FALSE,
+                                         ...) {
   rule <- attributes(x)$rule
   rope <- attributes(x)$rope
 
@@ -334,26 +333,6 @@ print_md.equivalence_test_lm <- function(x, digits = 2, ci_brackets = c("(", ")"
 }
 
 
-
-
-
-# distribution print ----------------------------
-
-#' @export
-print_md.parameters_distribution <- function(x, digits = 2, ci_brackets = c("(", ")"), ...) {
-  formatted_table <- format(
-    x = x,
-    digits = digits,
-    format = "markdown",
-    ci_width = NULL,
-    ci_brackets = ci_brackets,
-    ...
-  )
-
-  insight::export_table(formatted_table, format = "markdown", align = "firstleft", ...)
-}
-
-
 # helper -----------------------
 
 .export_table_tt <- function(x, formatted_table, groups, caption = NULL, footer = NULL, outformat = "markdown") {
